@@ -1,12 +1,13 @@
 import argparse
+import tomllib
 import os
 
 
 def main():
     # First, find the current package version number from the pyproject.toml file
-    with open("pyproject.toml", "r") as f:
-        setup = f.read()
-    version = setup.split("version = ")[1].split(",")[0].strip('"')
+    with open("pyproject.toml", "rb") as f:
+        data = tomllib.load(f)
+        version = data["project"]["version"]  # Would give us "1.358.0"
     # Then, clone the https://github.com/policyengine/policyengine-api repo using the GitHub CLI
     pat = os.environ["GITHUB_TOKEN"]
     os.system(
@@ -19,7 +20,7 @@ def main():
 
     # Repeat the above for https://github.com/policyengine/policyengine-household-api
     os.system(
-        f"git clone https://nikhilwodruff:{pat}@github.com/policyengine/policyengine-household-api"
+        f"git clone https://nikhilwoodruff:{pat}@github.com/policyengine/policyengine-household-api"
     )
 
     os.system(
