@@ -289,6 +289,11 @@ class SelectiveTestRunner:
 
             # Special handling for test files themselves
             if "tests" in file and file.endswith(".py"):
+                # Skip test infrastructure files that shouldn't trigger all tests
+                if file.endswith(
+                    ("run_selective_tests.py", "test_batched.py")
+                ):
+                    continue
                 # Add the directory containing the test file
                 test_dir = os.path.dirname(file)
                 if test_dir:
@@ -314,7 +319,13 @@ class SelectiveTestRunner:
 
         return existing_test_paths
 
-    def run_tests(self, test_paths: Set[str], verbose: bool = False) -> int:
+    def run_tests(
+        self,
+        test_paths: Set[str],
+        verbose: bool = False,
+        with_coverage: bool = False,
+        changed_files: Set[str] = None,
+    ) -> int:
         """Run pytest on specified test paths."""
         if not test_paths:
             print("No relevant tests found for changed files.")
@@ -325,7 +336,86 @@ class SelectiveTestRunner:
             print(f"  - {path}")
 
         # Construct pytest command
-        pytest_args = ["policyengine-core", "test", "-c", "policyengine_us"]
+        if with_coverage:
+            # Use coverage to run the tests
+            import sys
+
+            # First check if coverage is importable
+            try:
+                import coverage
+
+                print(f"Coverage version: {coverage.__version__}")
+            except ImportError as e:
+                print(f"ERROR: Coverage module not found: {e}")
+                print(
+                    "Please ensure coverage is installed: pip install coverage"
+                )
+                return 1
+
+            # Only track coverage for the specific files that changed in the PR
+            include_patterns = []
+            if changed_files:
+                # Only include Python files that were actually changed (excluding test directories)
+                changed_py_files = [
+                    f
+                    for f in changed_files
+                    if f.endswith(".py") and "/tests/" not in f
+                ]
+                if changed_py_files:
+                    include_patterns = changed_py_files
+            else:
+                # Fallback to directory-based patterns if no changed files provided
+                for test_path in test_paths:
+                    # Convert test path to variable path
+                    if "tests/policy/baseline/" in test_path:
+                        var_path = test_path.replace(
+                            "tests/policy/baseline/", "variables/"
+                        )
+                        include_patterns.append(f"{var_path}/**/*.py")
+                        include_patterns.append(f"{var_path}/*.py")
+                    elif "tests/policy/reform/" in test_path:
+                        include_patterns.append(
+                            "policyengine_us/reforms/**/*.py"
+                        )
+                        include_patterns.append("policyengine_us/reforms/*.py")
+                    elif "tests/policy/contrib/" in test_path:
+                        include_patterns.append(
+                            "policyengine_us/parameters/contrib/**/*.py"
+                        )
+                        include_patterns.append(
+                            "policyengine_us/parameters/contrib/*.py"
+                        )
+
+            pytest_args = [
+                sys.executable,
+                "-m",
+                "coverage",
+                "run",
+                "-a",
+                "--branch",
+            ]
+
+            # Add --include flag to only track relevant files
+            if include_patterns:
+                include_pattern = ",".join(include_patterns)
+                pytest_args.extend(["--include", include_pattern])
+
+            pytest_args.extend(
+                [
+                    "-m",
+                    "policyengine_core.scripts.policyengine_command",
+                    "test",
+                    "-c",
+                    "policyengine_us",
+                ]
+            )
+        else:
+            pytest_args = [
+                "policyengine-core",
+                "test",
+                "-c",
+                "policyengine_us",
+            ]
 
         # Add test paths
         pytest_args.extend(sorted(test_paths))
@@ -409,6 +499,11 @@ def main():
         action="store_true",
         help="Show debug information about git state",
     )
+    parser.add_argument(
+        "--coverage",
+        action="store_true",
+        help="Run tests with coverage measurement",
+    )
 
     args = parser.parse_args()
 
@@ -508,7 +603,14 @@ def main():
         print("Consider running all tests with --all flag.")
         sys.exit(0)
 
-    sys.exit(runner.run_tests(test_paths, verbose=args.verbose))
+    sys.exit(
+        runner.run_tests(
+            test_paths,
+            verbose=args.verbose,
+            with_coverage=args.coverage,
+            changed_files=changed_files if args.coverage else None,
+        )
+    )
 
 
 if __name__ == "__main__":
