@@ -12,6 +12,13 @@ class il_tanf_assistance_unit_fpg(Variable):
         n = spm_unit("il_tanf_assistance_unit_size", period)
         state_group = spm_unit.household("state_group_str", period)
         p_fpg = parameters(period).gov.hhs.fpg
-        p1 = p_fpg.first_person[state_group] / MONTHS_IN_YEAR
-        pn = p_fpg.additional_person[state_group] / MONTHS_IN_YEAR
-        return p1 + pn * (n - 1)
+        year = period.start.year
+        month = period.start.month
+        if month >= 10:
+            instant_str = f"{year}-10-01"
+        else:
+            instant_str = f"{year - 1}-10-01"
+        p_fpg = parameters(instant_str).gov.hhs.fpg
+        p1 = p_fpg.first_person[state_group]
+        pn = p_fpg.additional_person[state_group]
+        return (p1 + pn * (n - 1)) / MONTHS_IN_YEAR
