@@ -7,4 +7,4 @@ class over_the_counter_health_expenses(Variable):
     label = "Over the counter health expenses"
     unit = USD
     definition_period = YEAR
-    uprating = "gov.bls.cpi.cpi_u"
+    uprating = "calibration.gov.hhs.cms.moop_per_capita"
